<?php

/**
 * @file
 * Admin page callbacks for the path_blacklist module.
 */

/**
 * Creates form to set blacklisted paths.
 */
function path_blacklist_settings_form() {
  
  $form['blacklist'] = array(
    '#title' => t('Unavailable paths'),
    '#type' => 'textarea',
    '#description' => 'Enter one page per line as Drupal paths. The \'*\' character is a wildcard. Do not include initial or trailing slashes.',
    '#default_value' => variable_get('path_blacklist_paths', ''),
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Submit',
  );
  
  $form['#validate'][] = 'path_blacklist_settings_form_validate';
  $form['#submit'][] = 'path_blacklist_settings_form_submit';
  
  return $form;
}

/**
 * Validator for path_blacklist_settings_form().
 */
function path_blacklist_settings_form_validate($form, &$form_state) {
  $paths = explode("\n", $form_state['values']['blacklist']);
  foreach ($paths as $path) {
    $path = trim($path);
    if (substr($path, 0, 1) == '/' || substr($path, -1) == '/') {
      form_set_error('blacklist', t('Paths can\'t begin or end with \'/\'.'));
    }
  }
}

/**
 * Submit handler for path_blacklist_settings_form().
 */
function path_blacklist_settings_form_submit($form, &$form_state) {
  variable_set('path_blacklist_paths', $form_state['values']['blacklist']);
  drupal_set_message(t('Your path blacklist has been successfully saved.'));
}